<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Category;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;


class AuthController extends Controller

{

    public function signin()
    {
        return view('frontend.signin');
    }
    public function signinform(Request $request)
    {
        $user = $request->validate([
            'email' => ['required', 'string', 'email', 'max:255'],
            'password' => ['required', 'string', 'min:4', 'max:20'],
        ]);
        if (Auth::attempt($user)) {

            if (Auth::user()->usertype == 'admin') {
                return redirect()->route('dashboard')->with('success', 'Login Successfully');
            } else {
                return redirect()->route('home')->with('success', 'Login Successfully');
            }
        } else {
            return redirect()->back()->with(['failure' => 'Invalid credentials']);
        }
    }
    public function logout()
    {
        Auth::logout();
        return redirect()->route('home')->with('success', 'Logout Successfully');
    }



    public function signup()
    {
        return view('frontend.signup');
    }
    public function signupform(Request $request)
    {
        $user = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:user'],
            'password' => ['required', 'string', 'min:4', 'confirmed'],

        ]);

        if (User::create($user)) {
            return redirect()->route('signin')->with('success', 'Registration Successfully');
        } else {
            return redirect()->back()->with(['failure' => 'Registration Failed']);
        }
    }
    public function usershow(Request $request)
    {
        $userdata = User::latest();
        if (!empty($request->get('keyword'))) {
            $userdata = $userdata->where('name', 'like', '%' . $request->get('keyword') . '%');
        }
        $userdata = $userdata->paginate(5);
        return view('dashboard.user.show', ['userdata' => $userdata]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function useredit(string $id)
    {
        $userdata = User::find($id);
        return view('dashboard.user.edit', ['userdata' => $userdata]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function userupdate(Request $request, string $id)
    {
        $user = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255'],
            'password' => ['required', 'string', 'min:4', 'confirmed'],
        ]);

        if (User::find($id)->update($user)) {
            return redirect()->route('usershow')->with('success', 'User updated Successfully');
        } else {
            return redirect()->back()->with(['failure' => 'User update Failed']);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function userdelete(string $id)
    {
        $user = User::find($id);
        if ($user) {
            $user->delete();
            return redirect()->back()->with('success', 'User data moved to trash successfully');
        }
    }

    public function usertrash()
    {
        $datatrash = User::onlyTrashed()->paginate(10); // 10 items per page
        return view('dashboard.user.trash', ['datatrash' => $datatrash]);
    }
    public function userperment($id)
    {
        $data =  User::withTrashed()->find($id);
        $data->forceDelete();
        return redirect()->back()->with('success', 'User data permanently deleted successfully');
    }
    public function userrestore($id)
    {
        $data = User::withTrashed()->find($id);
        $data->restore();
        return redirect()->back()->with('success', 'user data restored successfully');
    }
}