<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Billings;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class Billing extends Controller
{
    public function showCheckoutPage()
    {
        $cart = session('cart', []);
        $total = array_sum(array_map(function ($item) {
            return $item['price'] * $item['quantity'];
        }, $cart));
        $categories = Category::all();

        return view('frontend.checkout', compact('cart', 'total', 'categories'));
    }
    public function placeOrder(Request $request)
    {
        session()->flash('order_completed', 'Your order has been successfully completed. Thank you for shopping with us!');
        session()->forget('cart');  // Clears the cart session

        return response()->json([
            'success' => true,
            'message' => 'Your order has been successfully completed. Thank you for shopping with us!'
        ]);
    }

    public function billingadd()
    {
        return view('frontend.billing');
    }
    public function billingcreate()
    {
        return view('dashboard.billing');
    }

    public function billingstore(Request $request)
    {
        $data = $request->validate([
            'first_name' => 'required|string|max:255',
            'last_name' => 'required|string|max:255',
            'country' => 'required|string|max:255',
            'address' => 'required|string|max:255',
            'street_address' => 'required|string|max:255',
            'apartment' => 'nullable|string|max:255', // Optional
            'town_city' => 'required|string|max:255',
            'state' => 'required|string|max:255',
            'postcode' => 'required|string|max:20',
            'phone' => 'required|min:10|max:15',
            'email' => 'required|email|unique:billings,email',
        ]);

        $billing = new Billings();
        $billing->first_name = $data['first_name'];
        $billing->last_name = $data['last_name'];
        $billing->country = $data['country'];
        $billing->address = $data['address'];
        $billing->street_address = $data['street_address'];
        $billing->apartment = $data['apartment'];
        $billing->town_city = $data['town_city'];
        $billing->state = $data['state'];
        $billing->postcode = $data['postcode'];
        $billing->phone = $data['phone'];
        $billing->email = $data['email'];

        $billing->save();

        return redirect()->back()->with('success', 'Your billing information has been successfully saved.');
    }

    public function billingshow(Request $request)
    {
        $billingdata = Billings::latest();
        if (!empty($request->get('keyword'))) {
            $billingdata = $billingdata->where('name', 'like', '%' . $request->get('keyword') . '%');
        }
        $billingdata = $billingdata->paginate(5);
        return view('dashboard\billing\show', ['billingdata' => $billingdata]);
    }

    // Show form for editing a blog
    public function billingedit($id)
    {
        $billingdata = Billings::find($id);
        return view('dashboard.billing.edit', compact('billingdata'));
    }

    public function billingupdate(Request $request,  $id)
    {
        $data = $request->validate([
            'first_name' => 'required|string|max:255',
            'last_name' => 'required|string|max:255',
            'country' => 'required|string|max:255',
            'address' => 'required|string|max:255',
            'street_address' => 'required|string|max:255',
            'apartment' => 'nullable|string|max:255', // Optional
            'town_city' => 'required|string|max:255',
            'state' => 'required|string|max:255',
            'postcode' => 'required|string|max:20',
            'phone' => 'required|min:10|max:15',
            'email' => 'required|email|unique:billings,email',
        ]);

        $billing = new Billings();
        $billing->first_name = $data['first_name'];
        $billing->last_name = $data['last_name'];
        $billing->country = $data['country'];
        $billing->address = $data['address'];
        $billing->street_address = $data['street_address'];
        $billing->apartment = $data['apartment'];
        $billing->town_city = $data['town_city'];
        $billing->state = $data['state'];
        $billing->postcode = $data['postcode'];
        $billing->phone = $data['phone'];
        $billing->email = $data['email'];

        $billing->save();

        return redirect()->back()->with('success', 'Billing updated successfully!');
    }

    public function billingdelete($id)
    {
        $billingdata = Billings::find($id);
        $billingdata->delete();
        return redirect()->back()->with('success', 'Billing data moved to trash successfully');
    }

    public function billingtrash()
    {
        $billingdata = Billings::onlyTrashed()->paginate(10); // 10 items per page
        return view('dashboard.billing.trash', ['billingdata' => $billingdata]);
    }
    public function billingperment($id)
    {
        $billingdata =  Billings::withTrashed()->find($id);
        $billingdata->forceDelete();
        return redirect()->back()->with('success', 'Billing data permanently deleted successfully');
    }
    public function billingrestore($id)
    {
        $billingdata = Billings::withTrashed()->find($id);
        $billingdata->restore();
        return redirect()->back()->with('success', 'Billing data restored successfully');
    }
}