<?php

namespace App\Http\Controllers;

use App\Models\Blog;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class BlogsController extends Controller
{

    // Display all blogs
    public function blogcreate()
    {
        $blogs = Blog::all();
        return view('dashboard\blog\add', compact('blogs'));
    }


    // Store a new blog
    public function blostore(Request $request)
    {
        $request->validate([
            'title' => 'required',
            'content' => 'required',
            'image' => 'required|image|mimes:jpeg,png,jpg|max:2048',
        ]);

        $imageName = time() . '.' . $request->image->extension();
        $request->image->move(public_path('Blog'), $imageName);
        $blog = new Blog;
        $blog->image = $imageName;
        $blog->title = $request->title;
        $blog->content = $request->content;
        $blog->save();
        return back()->with('success', 'Blog saved successfully');
    }

    // Display a specific blog
    public function blogshow(Request $request)
    {
        $blogdata = Blog::latest();
        if (!empty($request->get('keyword'))) {
            $blogdata = $blogdata->where('name', 'like', '%' . $request->get('keyword') . '%');
        }
        $blogdata = $blogdata->paginate(5);
        return view('dashboard\blog\show', ['blogdata' => $blogdata]);
    }

    // Show form for editing a blog
    public function blogedit($id)
    {
        $blog = Blog::find($id);
        return view('dashboard.blog.edit', compact('blog'));
    }

    // Update a specific blog
    public function blogupdate(Request $request,  $id)
    {
        $request->validate([
            'title' => 'required',
            'content' => 'required',
            'image' => 'sometimes|image|mimes:jpeg,png,jpg|max:2048',

        ]);
        $blog = Blog::findOrFail($id);

        if ($request->hasFile('image')) {
            if ($blog->image && file_exists(public_path($blog->image))) {
                unlink(public_path($blog->image));
            }

            $imageName = time() . '.' . $request->image->extension();
            $request->image->move(public_path('Blog'), $imageName);

            $blog->image = 'Blog/' . $imageName;
        }
        $blog->title = $request->title;
        $blog->content = $request->content;
        $blog->image = $imageName;
        $blog->save();

        return redirect()->back()->with('success', 'Blog updated successfully!');
    }

    // Delete a specific blog
    public function blogdelete($id)
    {
        $blog = Blog::find($id);
        $blog->delete();
        return redirect()->back()->with('success', 'Blog data moved to trash successfully');
    }

    public function blogtrash()
    {
        $blogdata = Blog::onlyTrashed()->paginate(10); // 10 items per page
        return view('dashboard.blog.trash', ['blogdata' => $blogdata]);
    }
    public function blogperment($id)
    {
        $data =  Blog::withTrashed()->find($id);
        $data->forceDelete();
        return redirect()->back()->with('success', 'Blog data permanently deleted successfully');
    }
    public function blogrestore($id)
    {
        $data = Blog::withTrashed()->find($id);
        $data->restore();
        return redirect()->back()->with('success', 'Blog data restored successfully');
    }
}