<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Category;


class CategoriesController extends Controller
{

    public function Categorycreate()
    {
        return view('dashboard.category.add');
    }
    public function Categorystore(Request $request)
    {
        $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'slug' => ['required', 'string', 'max:255'],
            'status' => ['required', 'integer', 'min:0', 'max:1'],
            'image' => 'required|image|mimes:jpeg,png,jpg|max:2048',
        ]);

        $imageName = time() . '.' . $request->image->extension();
        $request->image->move(public_path('Category'), $imageName);
        $product = new Category;
        $product->image = $imageName;
        $product->name = $request->name;
        $product->slug = $request->slug;
        $product->status = $request->status;

        $product->save();
        return back()->with('success', 'Category saved successfully');
    }
    public function Categoryshow(Request $request)
    {
        $categorydata = Category::latest();
        if (!empty($request->get('keyword'))) {
            $categorydata = $categorydata->where('name', 'like', '%' . $request->get('keyword') . '%');
        }
        $categorydata = $categorydata->paginate(5);
        return view('dashboard.category.show', ['categorydata' => $categorydata]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function Categoryedit(string $id)
    {
        $categorydata = Category::find($id);
        return view('dashboard.category.edit', ['categorydata' => $categorydata]);
    }

    /**
     * Update the specified resource in storage.
     */
    public function Categoryupdate(Request $request, string $id)
    {
        $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'slug' => ['required', 'string', 'max:255'],
            'status' => ['required', 'integer', 'min:0', 'max:1'],
            'image' => 'sometimes|image|mimes:jpeg,png,jpg|max:2048',
        ]);

        $clain = Category::findOrFail($id);

        if ($request->hasFile('image')) {
            if ($clain->image && file_exists(public_path($clain->image))) {
                unlink(public_path($clain->image));
            }

            $imageName = time() . '.' . $request->image->extension();
            $request->image->move(public_path('Category'), $imageName);

            $clain->image = 'Category/' . $imageName;
        }
        $clain->name = $request->name;
        $clain->slug = $request->slug;
        $clain->status = $request->status;
        $clain->image = $imageName;
        $clain->save();

        return redirect()->back()->with('success', 'Category updated successfully!');
    }


    /**
     * Remove the specified resource from storage.
     */
    public function categorydelete(string $id)
    {
        $user = Category::find($id);
        if ($user) {
            $user->delete();
            return redirect()->back()->with('success', 'Category data moved to trash successfully');
        }
    }

    public function Categorytrash()
    {
        $categorydata = Category::onlyTrashed()->paginate(10); // 10 items per page
        return view('dashboard.category.trash', ['categorydata' => $categorydata]);
    }
    public function categoryperment($id)
    {
        $data =  Category::withTrashed()->find($id);
        $data->forceDelete();
        return redirect()->back()->with('success', 'Category data permanently deleted successfully');
    }
    public function categoryrestore($id)
    {
        $data = Category::withTrashed()->find($id);
        $data->restore();
        return redirect()->back()->with('success', 'Category data restored successfully');
    }
}