<?php

namespace App\Http\Controllers;

use App\Models\Contact;
use Illuminate\Http\Request;

class ContactController extends Controller
{

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function contactstore(Request $request)
    {
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'content' => 'required|string|min:10',
        ]);

        $contact = new Contact();
        $contact->name = $validatedData['name'];
        $contact->email = $validatedData['email'];
        $contact->content = $validatedData['content'];

        $contact->save();

        return back()->with('success', 'Message sent successfully!');
    }
    /**
     * Display the specified resource.
     */

    public function contactshow(Request $request)
    {
        $contactdata = Contact::latest();
        if (!empty($request->get('keyword'))) {
            $contactdata = $contactdata->where('name', 'like', '%' . $request->get('keyword') . '%');
        }
        $contactdata = $contactdata->paginate(5);
        return view('dashboard\contact\show', ['contactdata' => $contactdata]);
    }

    // Show form for editing a blog
    public function contactedit($id)
    {
        $contact = Contact::find($id);
        return view('dashboard.contact.edit', compact('contact'));
    }

    // Update a specific blog
    public function contactupdate(Request $request,  $id)
    {
        $validatedData = $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'content' => 'required|string|min:10',
        ]);

        $contact = new Contact();
        $contact->name = $validatedData['name'];
        $contact->email = $validatedData['email'];
        $contact->content = $validatedData['content'];

        $contact->save();

        return back()->with('success', 'Contact data updated successfully!');
    }

    // Delete a specific blog
    public function contactdelete($id)
    {
        $blog = Contact::find($id);
        $blog->delete();
        return redirect()->back()->with('success', 'Contact data moved to trash successfully');
    }

    public function contacttrash()
    {
        $contactdata = Contact::onlyTrashed()->paginate(10); // 10 items per page
        return view('dashboard.contact.trash', ['contactdata' => $contactdata]);
    }
    public function contactperment($id)
    {
        $data =  Contact::withTrashed()->find($id);
        $data->forceDelete();
        return redirect()->back()->with('success', 'Contact data permanently deleted successfully');
    }
    public function contactrestore($id)
    {
        $data = Contact::withTrashed()->find($id);
        $data->restore();
        return redirect()->back()->with('success', 'Contact data restored successfully');
    }
}