<?php

namespace App\Http\Controllers;

use App\Models\Blog;
use App\Models\Category;
use App\Models\Products;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Controller;


class FrontendController extends Controller
{
    public function index($categoryId = null)
    {
        $latestProducts = Products::where('category_id', 12)->get(); // Replace '1' with the actual ID for "Latest" category
        $topRatedProducts = Products::where('category_id', 11)->get(); // Replace '2' with the ID for "Top Rated" category
        $reviewProducts = Products::where('category_id', 10)->get(); // Replace '3' with the ID for "Reviewed" category

        $categories = Category::all();
        $blogs = Blog::all();


        if ($categoryId) {
            $featuredProducts = Products::where('category_id', $categoryId)->inRandomOrder()->limit(8)->get(); // Random 8 products from specified category
        } else {
            $featuredProducts = Products::inRandomOrder()->limit(12)->get(); // Random 8 products from all categories if no categoryId is specified
        }

        return view('frontend.index', compact('categories', 'latestProducts', 'topRatedProducts', 'reviewProducts', 'featuredProducts', 'blogs'));
    }
    public function search(Request $request)
    {
        $query = $request->input('query'); // Get the search query
        $categories = Category::all();
        if ($query) {
            $featuredProducts = Products::where('name', 'LIKE', '%' . $query . '%')->get();
        } else {
            $featuredProducts = Products::all(); // Fetch all products if no query is specified
        }
        $latestProducts = Products::where('category_id', 10)->get(); // Update IDs as needed
        $topRatedProducts = Products::where('category_id', 12)->get(); // Update IDs as needed
        $reviewProducts = Products::where('category_id', 11)->get(); // Update IDs as needed
        return view('frontend.shop-grid', compact('categories', 'latestProducts', 'topRatedProducts', 'reviewProducts', 'featuredProducts'));
    }
    public function show($id)
    {
        $product = Products::findOrFail($id); // Fetch the product by ID

        return view('frontend.shop-details', compact('product'));
    }
    public function shoppage($categoryId = null, $sort = null)
    {
        $topRatedProducts = Products::where('category_id', 10)->get();
        $reviewProducts = Products::where('category_id', 12)->get();
        if ($categoryId) {
            $featuredProducts = Products::where('category_id', $categoryId);
        } else {
            // Otherwise, get all products
            $featuredProducts = Products::query();
        }

        if ($sort === 'asc') {
            $featuredProducts = $featuredProducts->orderBy('price', 'asc'); // Sort low to high
        } elseif ($sort === 'desc') {
            $featuredProducts = $featuredProducts->orderBy('price', 'desc'); // Sort high to low
        }

        $featuredProducts = $featuredProducts->paginate(12);

        $categories = Category::all();


        // Return the view with the necessary data
        return view('frontend.shop-grid', compact('categories', 'reviewProducts', 'topRatedProducts', 'featuredProducts'));
    }

    public function showShopDetails()
    {
        $products = Products::all();
        $saleProducts = Products::all();
        $totalProductsCount = $products->count();


        // Passing data as an array
        return view('frontend.shop-grid', [
            'saleProducts' => $saleProducts,
            'totalProductsCount' => $totalProductsCount
        ]);
    }


    public function toggleSaleStatus($id)
    {
        // Find the product by ID
        $product = Products::find($id);
        if ($product) {
            // Toggle the sale status
            $product->is_on_sale = !$product->is_on_sale;
            $product->save();
            return redirect()->back()->with('message', 'Product sale status updated!');
        }
        return redirect()->back()->with('error', 'Product not found!');
    }

    public function shopdetail()
    {
        $products = Products::all();
        $categories = Category::all();
        return view('frontend.shop-details', compact('products', 'categories'));
    }


    public function showdetail($id)
    {
        $productdetail = Products::find($id);

        if (!$productdetail) {
            abort(404);
        }

        $categories = Category::all();

        return view('frontend.shop-details', ['productdetail' => $productdetail, 'categories' => $categories]);
    }

    public function shoppingcard()
    {
        $categories = Category::all();
        return view('frontend.shoping-cart', ['categories' => $categories]);
    }

    public function blogpage($id)
    {
        $blog = Blog::find($id);

        if (!$blog) {
            return redirect()->route('blogpage')->with('error', 'Blog not found!');
        }
        $blog = Blog::find($id);
        $categories = Category::all();
        return view('frontend.blog-details', compact('blog', 'categories'));
    }
    public function blogshow()
    {
        $categories = Category::all();
        $blogs = Blog::all();
        return view('frontend.blog', compact('blogs', 'categories'));
    }

    public function billing()
    {
        $categories = Category::all();

        return view('frontend.checkout', ['categories' => $categories]);
    }

    public function contact()
    {
        $categories = Category::all();

        return view('frontend.contact', ['categories' => $categories]);
    }
}