<?php

namespace App\Http\Controllers;

use App\Models\Category;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Products;

class ProductsController extends Controller
{
    public function productsadd()
    {
        $categories = Category::all();
        return view('dashboard.product.add', compact('categories'));
    }

    public function productsshow(Request $request)
    {
        $query = Products::latest();
        if (!empty($request->get('keyword'))) {
            $query->where('name', 'like', '%' . $request->get('keyword') . '%');
        }
        $products = $query->paginate(5);
        $categories = Category::all();
        return view('dashboard.product.show', [
            'products' => $products,
            'categories' => $categories,
        ]);
    }

    public function productsstore(Request $request)
    {
        $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'slug' => ['required', 'string', 'max:255', 'unique:products,slug'],
            'description' => ['nullable', 'string'],
            'price' => ['required', 'numeric', 'min:0'],
            'stock' => ['required', 'integer', 'min:0'],
            'status' => ['required', 'integer', 'min:0', 'max:1'],
            'is_on_sale' => 'boolean', // Validate as boolean
            'category_id' => ['required', 'exists:categories,id'],
            'image' => 'required|image|mimes:jpeg,png,jpg|max:2048',
        ]);

        $imageName = time() . '.' . $request->image->extension();
        $request->image->move(public_path('Product'), $imageName);

        $product = new Products;
        $product->image = '/' . $imageName;
        $product->name = $request->name;
        $product->slug = $request->slug;
        $product->description = $request->description;
        $product->is_on_sale = $request->has('is_on_sale'); // Set to true if checked

        $product->price = $request->price;
        $product->stock = $request->stock;
        $product->status = $request->status;
        $product->category_id = $request->category_id;

        $product->save();
        return back()->with('success', 'Product created successfully');
    }
    public function productsedit($id)
    {
        $product = Products::findOrFail($id); // Fetch the product by ID
        $categories = Category::all(); // Fetch all categories

        return view('dashboard.product.edit', compact('product', 'categories'));
    }


    public function productsupdate(Request $request, string $id)
    {
        $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'slug' => ['required', 'string', 'max:255', 'unique:products,slug,' . $id],
            'description' => ['nullable', 'string'],
            'price' => ['required', 'numeric', 'min:0'],
            'stock' => ['required', 'integer', 'min:0'],
            'status' => ['required', 'integer', 'min:0', 'max:1'],
            'category_id' => ['required', 'exists:categories,id'],
            'is_on_sale' => 'boolean', // Validate as boolean
            'image' => 'sometimes|image|mimes:jpeg,png,jpg|max:2048',
        ]);

        $product = Products::findOrFail($id);

        if ($request->hasFile('image')) {
            if ($product->image && file_exists(public_path($product->image))) {
                unlink(public_path($product->image));
            }

            $imageName = time() . '.' . $request->image->extension();
            $request->image->move(public_path('Product'), $imageName);
            $product->image = '/' . $imageName;
        }

        $product->name = $request->name;
        $product->slug = $request->slug;
        $product->description = $request->description;
        $product->price = $request->price;
        $product->is_on_sale = $request->has('is_on_sale'); // Set to true if checked
        $product->stock = $request->stock;
        $product->status = $request->status;
        $product->category_id = $request->category_id;

        $product->save();

        return redirect()->back()->with('success', 'Product updated successfully!');
    }

    public function productsdelete(string $id)
    {
        $product = Products::find($id);
        if ($product) {
            $product->delete();
            return redirect()->back()->with('success', 'Product moved to trash successfully');
        }
        return redirect()->back()->with('error', 'Product not found');
    }

    public function productstrash()
    {
        $productdata = Products::onlyTrashed()->paginate(10);
        $categories = Category::all(); // Fetch all categories

        return view('dashboard.product.trash', [
            'productdata' => $productdata,
            'categories' => $categories
        ]);
    }



    public function productsperment(string $id)
    {
        $product = Products::withTrashed()->find($id);
        if ($product) {
            $product->forceDelete();
            return redirect()->back()->with('success', 'Product permanently deleted successfully');
        }
        return redirect()->back()->with('error', 'Product not found');
    }

    public function productsrestore(string $id)
    {
        $product = Products::withTrashed()->find($id);
        if ($product) {
            $product->restore();
            return redirect()->back()->with('success', 'Product restored successfully');
        }
        return redirect()->back()->with('error', 'Product not found');
    }


    public function searchproducts(Request $request)
    {
        $query = $request->input('query');
        $sort = $request->input('sort', 'default');

        $categories = Category::all();

        $featuredProducts = Products::when($query, function ($queryBuilder) use ($query) {
            return $queryBuilder->where('name', 'LIKE', '%' . $query . '%')
                ->orWhere('description', 'LIKE', '%' . $query . '%'); // Added description search
        });

        if ($sort == 'low_high') {
            $featuredProducts = $featuredProducts->orderBy('price', 'asc'); // Low to High
        } elseif ($sort == 'high_low') {
            $featuredProducts = $featuredProducts->orderBy('price', 'desc'); // High to Low
        }

        $featuredProducts = $featuredProducts->paginate(12);

        $latestProducts = Products::where('category_id', 1)->get();
        $topRatedProducts = Products::where('category_id', 2)->get();
        $reviewProducts = Products::where('category_id', 3)->get();

        return view('frontend.shop-grid', compact('categories', 'latestProducts', 'topRatedProducts', 'reviewProducts', 'featuredProducts'));
    }
}