<?php

namespace App\Http\Controllers;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Subcategory;
use Illuminate\Http\Request;

class SubController extends Controller
{


    public function subcategoryadd()
    {
        $categories = Category::all();
        return view('dashboard.subcategory.add', compact('categories'));
    }

    public function subcategorystore(Request $request)
    {
        $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'slug' => ['required', 'string', 'max:255'],
            'status' => ['required', 'integer', 'min:0', 'max:1'],
            'category_id' => 'required|exists:categories,id',
        ]);

        $subcategory = new Subcategory([
            'name' => $request->name,
            'slug' => $request->slug,
            'status' => $request->status,
            'category_id' => $request->category_id,
        ]);

        $subcategory->save();

        return redirect()->back()->with('success', 'Subcategory created successfully.');
    }


    public function subcategoryshow(Request $request)
    {
        $subcategorydata = Subcategory::latest();
        if (!empty($request->get('keyword'))) {
            $subcategorydata = $subcategorydata->where('name', 'like', '%' . $request->get('keyword') . '%');
        }
        $subcategorydata = $subcategorydata->paginate(5);
        return view('dashboard.subcategory.show', ['subcategorydata' => $subcategorydata]);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function subcategoryedit(string $id)
    {
        $subcategorydata = Subcategory::findOrFail($id);
        $categories = Category::all();
        return view('dashboard.subcategory.edit', [
            'subcategorydata' => $subcategorydata,
            'categories' => $categories
        ]);
    }


    /**
     * Update the specified resource in storage.
     */
    public function subcategoryupdate(Request $request, string $id)
    {
        $validatedData = $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'slug' => ['required', 'string', 'max:255'],
            'status' => ['required', 'integer', 'min:0', 'max:1'],
            'category_id' => 'required|exists:categories,id',
        ]);
        $subcategory = Subcategory::findOrFail($id);
        $subcategory->update($validatedData);

        return redirect()->back()->with('success', 'Subcategory updated successfully!');
    }



    /**
     * Remove the specified resource from storage.
     */
    public function subcategorydelete(string $id)
    {
        $user = Subcategory::find($id);
        if ($user) {
            $user->delete();
            return redirect()->back()->with('success', 'Subcategory data moved to trash successfully');
        }
    }

    public function subcategorytrash()
    {
        $subcategorydata = Subcategory::onlyTrashed()->paginate(10); // 10 items per page
        return view('dashboard.subcategory.trash', ['subcategorydata' => $subcategorydata]);
    }
    public function subcategoryperment($id)
    {
        $data =  Subcategory::withTrashed()->find($id);
        $data->forceDelete();
        return redirect()->back()->with('success', 'Subcategory data permanently deleted successfully');
    }
    public function subcategoryrestore($id)
    {
        $data = Subcategory::withTrashed()->find($id);
        $data->restore();
        return redirect()->back()->with('success', 'Subcategory data restored successfully');
    }
}