@extends('dashboard.main')

@section('main-container')
    <style>
        .btn-circle {
            border-radius: 50%;
            width: 40px;
            height: 40px;
            display: flex;
            justify-content: center;
            align-items: center;
            padding: 0;
            border: 1px solid white;
        }

        .btn-circle:hover {
            background-color: red;
            color: white;
        }

        .form-select,
        .form-control {
            background-color: #000;
            color: white;
        }

        .form-control::placeholder {
            color: #ccc;
        }

        .form-select:focus,
        .form-control:focus {
            border-color: red;
            box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, .25);
        }

        .custom-file-input {
            display: none;
        }

        .custom-file-label {
            background-color: #000;
            color: white;
            border: 1px solid white;
            padding: 10px;
            border-radius: 4px;
            width: 100%;
            text-align: center;
        }
    </style>
    <div class="container my-4">
        <div class="d-flex align-items-center mb-4">
            <a href="{{ route('productsshow') }}" class="btn btn-dark btn-circle me-3">
                <i class="bi bi-arrow-left"></i>
            </a>
            <h1 class="h3 mx-auto"><strong>Edit Product</strong></h1>
        </div>

        <form action="{{ route('productsupdate', $product->id) }}" method="POST" class="border p-4 rounded shadow-sm"
            enctype="multipart/form-data">
            @csrf

            <div class="mb-3 row">
                <label for="name" class="form-label col-sm-2 col-form-label">Name</label>
                <div class="col-sm-10">
                    <input type="text" class="form-control" name="name" id="name" placeholder="Enter name"
                        value="{{ old('name', $product->name) }}">
                    <p class="text-danger">
                        @error('name')
                            {{ $message }}
                        @enderror
                    </p>
                </div>
            </div>

            <div class="mb-3 row">
                <label for="slug" class="form-label col-sm-2 col-form-label">Slug</label>
                <div class="col-sm-10">
                    <input type="text" class="form-control" name="slug" id="slug" placeholder="slug"
                        value="{{ old('slug', $product->slug) }}">
                    <p class="text-danger">
                        @error('slug')
                            {{ $message }}
                        @enderror
                    </p>
                </div>
            </div>

            <div class="mb-3 row">
                <label for="description" class="form-label col-sm-2 col-form-label">Description</label>
                <div class="col-sm-10">
                    <textarea class="form-control" name="description" id="description" placeholder="Enter description">{{ old('description', $product->description) }}</textarea>
                    <p class="text-danger">
                        @error('description')
                            {{ $message }}
                        @enderror
                    </p>
                </div>
            </div>

            <div class="mb-3 row">
                <label for="price" class="form-label col-sm-2 col-form-label">Price</label>
                <div class="col-sm-10">
                    <input type="number" class="form-control" name="price" id="price" placeholder="Enter price"
                        value="{{ old('price', $product->price) }}">
                    <p class="text-danger">
                        @error('price')
                            {{ $message }}
                        @enderror
                    </p>
                </div>
            </div>

            <div class="mb-3 row">
                <label for="stock" class="form-label col-sm-2 col-form-label">Stock</label>
                <div class="col-sm-10">
                    <input type="number" class="form-control" name="stock" id="stock" placeholder="Enter stock"
                        value="{{ old('stock', $product->stock) }}">
                    <p class="text-danger">
                        @error('stock')
                            {{ $message }}
                        @enderror
                    </p>
                </div>
            </div>

            <div class="mb-3 row">
                <label for="status" class="form-label col-sm-2 col-form-label">Status</label>
                <div class="col-sm-10">
                    <select name="status" id="status" class="form-select">
                        <option value="1" {{ $product->status == 1 ? 'selected' : '' }}>Active</option>
                        <option value="0" {{ $product->status == 0 ? 'selected' : '' }}>Block</option>
                    </select>
                    <p class="text-danger">
                        @error('status')
                            {{ $message }}
                        @enderror
                    </p>
                </div>
            </div>

            <div class="mb-3 row">
                <label for="category_id" class="form-label col-sm-2 col-form-label">Category</label>
                <div class="col-sm-10">
                    <select name="category_id" id="category_id" class="form-select">
                        @foreach ($categories as $category)
                            <option value="{{ $category->id }}"
                                {{ $product->category_id == $category->id ? 'selected' : '' }}>{{ $category->name }}
                            </option>
                        @endforeach
                    </select>
                    <p class="text-danger">
                        @error('category_id')
                            {{ $message }}
                        @enderror
                    </p>
                </div>
            </div>
            <div class="mb-3 row">
                <label for="is_on_sale" class="form-label col-sm-2 col-form-label">Is On Sale</label>
                <div class="col-sm-10">
                    <input type="checkbox" name="is_on_sale" id="is_on_sale" value="1" class="form-check-input">
                    <label for="is_on_sale" class="form-check-label">Check if the product is on sale</label>
                    <p class="text-danger">
                        @error('is_on_sale')
                            {{ $message }}
                        @enderror
                    </p>
                </div>
            </div>

            <div class="mb-3 row">
                <label for="image" class="form-label col-sm-2 col-form-label">Image</label>
                <div class="col-sm-10">
                    <label for="image" class="custom-file-label">No file chosen</label>
                    <input type="file" class="custom-file-input" name="image" id="image" accept="image/*"
                        onchange="updateFileName()">
                    <p class="text-danger">
                        @error('image')
                            {{ $message }}
                        @enderror
                    </p>
                </div>
            </div>

            <button type="submit" class="btn btn-primary w-100">Update</button>
        </form>
    </div>

    <script>
        function updateFileName() {
            const fileInput = document.getElementById('image');
            const fileLabel = fileInput.previousElementSibling;
            const fileName = fileInput.files[0] ? fileInput.files[0].name : 'No file chosen';
            fileLabel.innerText = fileName;
        }
    </script>
@endsection
