@extends('dashboard.main')

@section('main-container')
    <style>
        .btn-circle {
            width: 40px;
            height: 40px;
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            padding: 0;
            border: 1px solid white;
        }

        .action-buttons {
            display: flex;
            gap: 10px;
            justify-content: center;
        }

        .btn-circle:hover {
            background-color: red;
            color: white;
        }

        .page-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

        .image-thumbnail {
            width: 50px;
            height: 50px;
            object-fit: cover;
            border-radius: 4px;
            border: 1px solid #ddd;
        }

        .alert {
            margin-bottom: 20px;
        }

        /* Custom styles for the heading */
        .h3 {
            margin-bottom: 20px;
        }
    </style>

    <div class="container my-4">
        <div class="page-header mb-4">
            <a href="{{ route('productsadd') }}" class="btn btn-dark" title="Add Product">
                <i class="bi bi-plus-lg"></i> Add Product
            </a>

            <h1 class="h3 text-center mx-auto"><strong>Product Management</strong></h1>

            <a href="{{ route('productstrash') }}" class="btn btn-dark btn-circle" title="View Trash">
                <i class="bi bi-person-x-fill"></i>
            </a>
        </div>



        @if ($errors->any())
            <div class="alert alert-danger">
                <ul>
                    @foreach ($errors->all() as $error)
                        <li>{{ $error }}</li>
                    @endforeach
                </ul>
            </div>
        @endif

        <table class="table table-striped table-bordered">
            <thead class="table-dark">
                <tr>
                    <th>ID</th>
                    <th>Name</th>
                    <th>Slug</th>
                    <th>Description</th>
                    <th>Price</th>
                    <th>Stock</th>
                    <th>Status</th>
                    <th>Category</th>
                    <th> Sale</th>
                    <th>Image</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                @foreach ($products as $product)
                    <tr>
                        <td>{{ $product->id }}</td>
                        <td class="text-left">{{ $product->name }}</td>
                        <td class="text-left">{{ $product->slug }}</td>
                        <td class="text-left">{{ $product->description }}</td>
                        <td class="text-left">{{ $product->price }}</td>
                        <td class="text-left">{{ $product->stock }}</td>
                        <td class="text-left">
                            @if ($product->status == 1)
                                <i class="bi bi-check-circle text-success" title="Active"></i> Active
                            @else
                                <i class="bi bi-x-circle text-danger" title="Blocked"></i> Blocked
                            @endif
                        </td>
                        <td class="text-left">
                            @if ($product->category_id)
                                {{ $categories->find($product->category_id)->name ?? 'No Category' }}
                            @else
                                <span>No Category</span>
                            @endif
                        </td>
                        <td class="text-left">
                            @if ($product->is_on_sale)
                                Sale
                            @else
                                Not Sale
                            @endif
                        </td>

                        <td class="text-center">
                            @if ($product->image)
                                <img src="{{ asset('Product/' . $product->image) }}" alt="Image"
                                    class="image-thumbnail">
                            @else
                                <span>No Image</span>
                            @endif
                        </td>
                        <td>
                            <div class="action-buttons">
                                <a href="{{ route('productsedit', $product->id) }}" class="btn btn-dark btn-circle"
                                    title="Edit">
                                    <i class="bi bi-pencil"></i>
                                </a>
                                <a href="{{ route('productsdelete', $product->id) }}" class="btn btn-dark btn-circle"
                                    title="Delete">
                                    <i class="bi bi-trash"></i>
                                </a>
                            </div>
                        </td>
                    </tr>
                @endforeach
            </tbody>
        </table>

        <div class="d-flex justify-content-center my-4">
            <nav aria-label="Page navigation">
                <ul class="pagination">
                    <li class="page-item {{ $products->onFirstPage() ? 'disabled' : '' }}">
                        <a class="btn btn-dark btn-circle me-3" href="{{ $products->previousPageUrl() }}"
                            aria-label="Previous">
                            <i class="bi bi-arrow-left"></i>
                        </a>
                    </li>
                    <li class="page-item {{ !$products->hasMorePages() ? 'disabled' : '' }}">
                        <a class="btn btn-dark btn-circle" href="{{ $products->nextPageUrl() }}" aria-label="Next">
                            <i class="bi bi-arrow-right"></i>
                        </a>
                    </li>
                </ul>
            </nav>
        </div>
    </div>
@endsection
