<!DOCTYPE html>
<html lang="zxx">

@include('frontend.layouts.head')

<style>
    .product-link {
        color: #333;
        font-size: 18px;
        font-weight: 600;
        text-decoration: none;
        display: block;
        margin-bottom: 5px;
        transition: color 0.3s ease;
    }

    .product-price {
        font-size: 16px;
        font-weight: 500;
        color: #28a745;
    }
</style>

<body>
    <!-- Page Preloder -->
    <div id="preloder">
        <div class="loader"></div>
    </div>
    <!-- Header Section Begin -->
    @include('frontend.layouts.header')


    <div class="hero__search">
    </div>

    <!-- Header Section End -->
    <main>
        @yield('content')
    </main>


    <!-- Categories Section Begin -->
    <section class="categories">
        <div class="container">
            <div class="row">
                <div class="categories__slider owl-carousel">
                    @foreach ($categories as $category)
                        <div class="col-lg-3">
                            <div class="categories__item set-bg"
                                data-setbg="{{ asset('Category/' . $category->image) }}">
                                <h5><a href="#">{{ $category->name }}</a></h5>
                            </div>
                        </div>
                    @endforeach
                </div>
            </div>
        </div>
    </section>

    <!-- Categories Section End -->

    <!-- Featured Section Begin -->
    <section class="featured spad">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <div class="section-title">
                        <h2>Featured Products</h2>
                    </div>
                    <div class="featured__controls">
                        <ul>
                            <li class="active" data-filter="*">All</li>
                            @foreach ($categories as $category)
                                <li data-filter=".{{ strtolower($category->name) }}">{{ $category->name }}</li>
                            @endforeach
                        </ul>
                    </div>
                </div>
            </div>
            <div class="row featured__filter">
                @foreach ($featuredProducts as $product)
                    <div class="col-lg-3 col-md-4 col-sm-6 mix {{ strtolower($product->category->name) }}">
                        <div class="featured__item">
                            <div class="featured__item__pic set-bg"
                                data-setbg="{{ asset('/Product' . $product->image) }}">
                                <ul class="featured__item__pic__hover">
                                    <li><a href="{{ route('productdetail', $product->id) }}">
                                            <i class="fa fa-shopping-cart"></i>
                                        </a></li>
                                </ul>
                            </div>
                            <div class="featured__item__text">{{ $product->name }}
                                <h5 class="product-price">{{ number_format($product->price, 2) }} Rs</h5>
                            </div>

                        </div>
                    </div>
                @endforeach
            </div>
        </div>
    </section>


    <!-- Featured Section End -->

    <!-- Banner Begin -->
    <div class="banner">
        <div class="container">
            <div class="row">
                <div class="col-lg-6 col-md-6 col-sm-6">
                    <div class="banner__pic">
                        <img src="{{ asset('banner1.jpg') }}" alt="">
                    </div>
                </div>
                <div class="col-lg-6 col-md-6 col-sm-6">
                    <div class="banner__pic">
                        <img src="{{ asset('banner2.png') }}" alt="">
                    </div>
                </div>
            </div>
        </div>
    </div>
    <!-- Banner End -->

    <!-- Latest Product Section Begin -->
    <section class="latest-product spad">
        <div class="container">
            <div class="row">
                <!-- Latest Products Section -->
                <div class="col-lg-4 col-md-6">
                    <div class="latest-product__text">
                        <h4>Latest Products</h4>
                        <div class="latest-product__slider owl-carousel">
                            @foreach ($reviewProducts as $product)
                                <div class="latest-product__slider__item">
                                    <a href="#" class="latest-product__item">
                                        <div class="latest-product__item__pic">
                                            <img src="{{ asset('Product/' . $product->image) }}"
                                                alt="{{ $product->name }}">
                                        </div>
                                        <div class="latest-product__item__text">
                                            <h6>{{ $product->name }}</h6>
                                            <span>{{ number_format($product->price, 2) }} Rs</span>
                                        </div>
                                    </a>
                                </div>
                            @endforeach
                        </div>
                    </div>
                </div>

                <!-- Top Rated Products Section -->
                <div class="col-lg-4 col-md-6">
                    <div class="latest-product__text">
                        <h4>Top Rated Products</h4>
                        <div class="latest-product__slider owl-carousel">
                            @foreach ($latestProducts as $product)
                                <div class="latest-product__slider__item">
                                    <a href="#" class="latest-product__item">
                                        <div class="latest-product__item__pic">
                                            <img src="{{ asset('Product/' . $product->image) }}"
                                                alt="{{ $product->name }}">
                                        </div>
                                        <div class="latest-product__item__text">
                                            <h6>{{ $product->name }}</h6>
                                            <span>{{ number_format($product->price, 2) }} Rs</span>
                                        </div>
                                    </a>
                                </div>
                            @endforeach
                        </div>
                    </div>
                </div>

                <!-- Review Products Section -->
                <div class="col-lg-4 col-md-6">
                    <div class="latest-product__text">
                        <h4>Review Products</h4>
                        <div class="latest-product__slider owl-carousel">
                            @foreach ($topRatedProducts as $product)
                                <div class="latest-product__slider__item">
                                    <a href="#" class="latest-product__item">
                                        <div class="latest-product__item__pic">
                                            <img src="{{ asset('Product/' . $product->image) }}"
                                                alt="{{ $product->name }}">
                                        </div>
                                        <div class="latest-product__item__text">
                                            <h6>{{ $product->name }}</h6>
                                            <span>{{ number_format($product->price, 2) }} Rs</span>
                                        </div>
                                    </a>
                                </div>
                            @endforeach
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>




    <!-- Latest Product Section End -->

    <!-- Blog Section Begin -->
    <section class="from-blog spad">
        <div class="container">
            <div class="row">
                <div class="col-lg-12">
                    <div class="section-title from-blog__title">
                        <h2>From The Blog</h2>
                    </div>
                </div>
            </div>

            <div class="col-lg-12 col-md-10 order-md-2 order-1">
                <div class="row" style="margin-left: 50px; margin-top: 50px;">
                    <div class="row">
                        @foreach ($blogs as $blog)
                            <div class="col-lg-6 col-md-6 col-sm-6">
                                <div class="blog__item">
                                    <div class="blog__item__pic">
                                        <!-- Display dynamic image -->
                                        <img src="{{ asset('Blog/' . $blog->image) }}" alt="{{ $blog->title }}">
                                    </div>
                                    <div class="blog__item__text">
                                        <ul>
                                            <!-- Display dynamic date -->
                                            <li><i class="fa fa-calendar-o"></i>
                                                {{ $blog->created_at->format('M d, Y') }}
                                            </li>
                                            <!-- Display dynamic comment count -->
                                            <li><i class="fa fa-comment-o"></i> {{ $blog->comments_count }}</li>
                                        </ul>
                                        <!-- Display dynamic title -->
                                        <h5><a href="{{ route('blogpage', $blog->id) }}">{{ $blog->title }}</a>
                                        </h5>
                                        <!-- Display a part of the content -->
                                        <p>{{ Str::limit($blog->content, 100) }}</p>
                                        <!-- Link to view the full post -->
                                        <a href="{{ route('blogpage', $blog->id) }}" class="blog__btn">READ MORE
                                            <span class="arrow_right"></span></a>
                                    </div>
                                </div>
                            </div>
                        @endforeach
                    </div>
                </div>
    </section>
    <!-- Blog Section End -->


    @include('frontend.layouts.footer')


    <!-- Js Plugins -->
    <script src="js/jquery-3.3.1.min.js"></script>
    <script src="js/bootstrap.min.js"></script>
    <script src="js/jquery.nice-select.min.js"></script>
    <script src="js/jquery-ui.min.js"></script>
    <script src="js/jquery.slicknav.js"></script>
    <script src="js/mixitup.min.js"></script>
    <script src="js/owl.carousel.min.js"></script>
    <script src="js/main.js"></script>

</body>

</html>
