<!doctype html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Sign Up</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css" rel="stylesheet"
        integrity="sha384-QWTKZyjpPEjISv5WaRU9OFeRpok6YctnYmDr5pNlyT2bRjXh0JMhjY6hW+ALEwIH" crossorigin="anonymous">
    <style>
        body {
            display: flex;
            align-items: center;
            justify-content: center;
            min-height: 100vh;
            background-color: #f0f2f5;
            margin: 0;
        }

        .container {
            max-width: 350px;
            background: linear-gradient(0deg, rgb(255, 255, 255) 0%, rgb(244, 247, 251) 100%);
            border-radius: 40px;
            padding: 25px 35px;
            border: 5px solid rgb(255, 255, 255);
            box-shadow: rgba(133, 189, 215, 0.878) 0px 30px 30px -20px;
            margin: 20px;
        }

        .heading {
            text-align: center;
            font-weight: 900;
            font-size: 30px;
            color: rgb(16, 137, 211);
        }

        .form {
            margin-top: 20px;
        }

        .form .input-container {
            position: relative;
            width: 100%;
            margin-top: 15px;
        }

        .form .input {
            width: 100%;
            background: white;
            border: none;
            padding: 15px 20px;
            border-radius: 20px;
            box-shadow: #cff0ff 0px 10px 10px -5px;
            border-inline: 2px solid transparent;
        }

        .form .input::placeholder {
            color: rgb(170, 170, 170);
        }

        .form .input:focus {
            outline: none;
            border-inline: 2px solid #12B1D1;
        }

        .form .eye-icon {
            position: absolute;
            right: 15px;
            top: 50%;
            transform: translateY(-50%);
            cursor: pointer;
            color: #888;
            font-size: 18px;
        }

        .form .file-input-container {
            margin-top: 15px;
        }

        .form .file-input {
            display: none;
        }

        .form .file-label {
            display: block;
            width: 100%;
            padding: 15px 20px;
            border-radius: 20px;
            background: linear-gradient(45deg, rgb(16, 137, 211) 0%, rgb(18, 177, 209) 100%);
            color: white;
            text-align: center;
            cursor: pointer;
            transition: background 0.2s;
        }

        .form .file-label:hover {
            background: linear-gradient(45deg, rgb(18, 177, 209) 0%, rgb(16, 137, 211) 100%);
        }

        .form .file-name {
            margin-top: 5px;
            text-align: center;
            color: rgb(16, 137, 211);
        }

        .form .login-button {
            display: block;
            width: 100%;
            font-weight: bold;
            background: linear-gradient(45deg, rgb(16, 137, 211) 0%, rgb(18, 177, 209) 100%);
            color: white;
            padding-block: 15px;
            margin: 20px auto;
            border-radius: 20px;
            box-shadow: rgba(133, 189, 215, 0.878) 0px 20px 10px -15px;
            border: none;
            transition: all 0.2s ease-in-out;
        }

        .form .login-button:hover {
            transform: scale(1.03);
            box-shadow: rgba(133, 189, 215, 0.878) 0px 23px 10px -20px;
        }

        .form .login-button:active {
            transform: scale(0.95);
            box-shadow: rgba(133, 189, 215, 0.878) 0px 15px 10px -10px;
        }

        .error-message {
            color: #d9534f;
            font-size: 13px;
            font-family: Arial, sans-serif;
            margin-top: 4px;
            font-weight: 500;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="heading">Sign Up</div>
        <form action="{{ route('signup') }}" class="form" method="POST">
            @csrf
            <div class="input-container">
                <input class="input" type="text" name="name" id="name" placeholder="Full Name"
                    value="{{ old('name') }}">
                @error('name')
                    <div class="error-message">{{ $message }}</div>
                @enderror
            </div>

            <div class="input-container">
                <input class="input" type="email" name="email" id="email" placeholder="E-mail"
                    value="{{ old('email') }}">
                @error('email')
                    <div class="error-message">{{ $message }}</div>
                @enderror
            </div>

            <div class="input-container">
                <input class="input" type="password" name="password" id="password" placeholder="Password">
                <span class="eye-icon" onclick="togglePassword('password')">👁️</span>
                @error('password')
                    <div class="error-message">{{ $message }}</div>
                @enderror
            </div>


            <div class="input-container">
                <input class="input" type="password" name="password_confirmation" id="confirm_password"
                    placeholder="Confirm Password" />
                <span class="eye-icon" onclick="togglePassword('confirm_password')">👁️</span>
                @error('password_confirmation')
                    <div class="error-message">{{ $message }}</div>
                @enderror
            </div>


            <input class="login-button" type="submit" value="Sign In">
        </form>
    </div>

    <script>
        function togglePassword(fieldId) {
            const passwordField = document.getElementById(fieldId);
            const eyeIcon = passwordField.nextElementSibling;
            if (passwordField.type === "password") {
                passwordField.type = "text";
                eyeIcon.textContent = "🙈";
            } else {
                passwordField.type = "password";
                eyeIcon.textContent = "👁️";
            }
        }

        function displayFileName() {
            const fileInput = document.getElementById('image');
            const fileLabel = document.getElementById('file-label');
            const fileNameDisplay = document.getElementById('file-name');
            const fileName = fileInput.files[0] ? fileInput.files[0].name : '';
            fileLabel.textContent = fileName; // Update label text to show selected file name
            fileNameDisplay.textContent = ''; // Clear file name display (optional)
        }
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js"
        integrity="sha384-YvpcrYf0tY3lHB60NNkmXc5s9fDVZLESaAA55NDzOxhy9GkcIdslK1eN7N6jIeHz" crossorigin="anonymous">
    </script>
</body>

</html>
