<?php

use App\Http\Controllers\Billing;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\SubController;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\CartController;
use App\Http\Controllers\AdminController;
use App\Http\Controllers\BlogsController;
use App\Http\Controllers\ContactController;
use App\Http\Controllers\FrontendController;
use App\Http\Controllers\ProductsController;
use App\Http\Controllers\CategoriesController;


//admin
Route::prefix('admin')->controller(AdminController::class)->middleware('admin')->group(function () {
    Route::get('/', 'dashboard')->name('dashboard');
});

//User
Route::prefix('/')->controller(AuthController::class)->middleware('admin')->group(function () {
    Route::get('/usershow', 'usershow')->name('usershow');
    Route::get('/useredit/{id}', 'useredit')->name('useredit');
    Route::post('/userupdate/{id}', 'userupdate')->name('userupdate');
    Route::get('/userdelete/{id}', 'userdelete')->name('userdelete');
    Route::get('/usertrash', 'usertrash')->name('usertrash');
    Route::get('/userperment/{id}', 'userperment')->name('userperment');
    Route::get('/userrestore/{id}', 'userrestore')->name('userrestore');
});

//products
Route::prefix('/')->controller(ProductsController::class)->middleware('admin')->group(function () {
    Route::get('/productsadd', 'productsadd')->name('productsadd');
    Route::post('/productsadd', 'productsstore');
    Route::get('/productsshow', 'productsshow')->name('productsshow');
    Route::get('/productsedit/{id}', 'productsedit')->name('productsedit');
    Route::post('/productsupdate/{id}', 'productsupdate')->name('productsupdate');
    Route::get('/productsdelete/{id}', 'productsdelete')->name('productsdelete');
    Route::get('/productstrash', 'productstrash')->name('productstrash');
    Route::get('/productsperment/{id}', 'productsperment')->name('productsperment');
    Route::get('/productsrestore/{id}', 'productsrestore')->name('productsrestore');
    Route::get('/searchproduct', 'searchproducts')->name('searchproducts');
});

//Sub_Category
Route::prefix('/')->controller(SubController::class)->middleware('admin')->group(function () {
    Route::get('/subcategoryadd', 'subcategoryadd')->name('subcategoryadd');
    Route::post('/subcategoryadd', 'subcategorystore');
    Route::get('/subcategoryshow', 'subcategoryshow')->name('subcategoryshow');
    Route::get('/subcategoryedit/{id}', 'subcategoryedit')->name('subcategoryedit');
    Route::post('/subcategoryupdate/{id}', 'subcategoryupdate')->name('subcategoryupdate');
    Route::get('/subcategorydelete/{id}', 'subcategorydelete')->name('subcategorydelete');
    Route::get('/subcategorytrash', 'subcategorytrash')->name('subcategorytrash');
    Route::get('/subcategoryperment/{id}', 'subcategoryperment')->name('subcategoryperment');
    Route::get('/subcategoryrestore/{id}', 'subcategoryrestore')->name('subcategoryrestore');
});

//Category
Route::prefix('/')->controller(CategoriesController::class)->middleware('admin')->group(function () {
    Route::get('/categoryadd', 'categorycreate')->name('categoryadd');
    Route::post('/categoryadd', 'Categorystore');
    Route::get('/categoryshow', 'categoryshow')->name('categoryshow');
    Route::get('/categoryedit/{id}', 'categoryedit')->name('categoryedit');
    Route::post('/categoryupdate/{id}', 'categoryupdate')->name('categoryupdate');
    Route::get('/categorydelete/{id}', 'categorydelete')->name('categorydelete');
    Route::get('/categorytrash', 'categorytrash')->name('categorytrash');
    Route::get('/categoryperment/{id}', 'categoryperment')->name('categoryperment');
    Route::get('/categoryrestore/{id}', 'categoryrestore')->name('categoryrestore');
});

//Authorization
Route::prefix('/')->controller(AuthController::class)->group(function () {
    Route::get('/signin', 'signin')->name('signin');
    Route::post('/signin', 'signinform');
    Route::get('/signup', 'signup')->name('signup');
    Route::post('/signup', 'signupform');
    Route::get('/logout', 'logout')->name('logout');
    Route::post('/logout', 'logout')->name('logout');
});

//Frontend
Route::prefix('frontend')->controller(FrontendController::class)->group(function () {
    Route::get('index', 'index')->name('home');
    Route::get('/category/{categoryId}', 'index');
    Route::get('/search', 'search')->name('searchproduct');
    Route::get('/product/{id}', 'show')->name('product.show');
    Route::get('/shop', 'shoppage')->name('shop');
    Route::get('/shop/{categoryId?}/{sort?}', 'shoppage')->name('shop.page');
    Route::get('/product/toggle-sale/{id}', 'toggleSaleStatus')->name('product.toggle-sale');
    Route::get('/shop-grid', 'showShopDetails')->name('shop.grid');
    Route::get('/shopdetail', 'shopdetail')->name('shopdetail');
    Route::get('/product/{id}', 'showdetail')->name('productdetail');
    Route::get('shoppingcard', 'shoppingcard')->name('shoppingcard');
    Route::get('/blog', 'blogpage')->name('blogpage');
    Route::get('/blog/{id}', 'blogpage')->name('blogshow');
    Route::get('/blog/{id}', [FrontendController::class, 'blogpage'])->name('blogpage');
    Route::get('/blogshow', 'blogshow')->name('blogshows');
    Route::get('/contact', 'contact')->name('contact');
});

//Blog
Route::prefix('/')->controller(BlogsController::class)->middleware('admin')->group(function () {
    Route::get('/blogadd', 'blogcreate')->name('blogadd');
    Route::post('/blogadd', 'blostore');
    Route::get('/blogshow', 'blogshow')->name('blogshow');
    Route::get('/search', 'search')->name('search');
    Route::get('/blogedit/{id}', 'blogedit')->name('blogedit');
    Route::post('/blogupdate/{id}', 'blogupdate')->name('blogupdate');
    Route::get('/blogdelete/{id}', 'blogdelete')->name('blogdelete');
    Route::get('/blogtrash', 'blogtrash')->name('blogtrash');
    Route::get('/blogperment/{id}', 'blogperment')->name('blogperment');
    Route::get('/blogrestore/{id}', 'blogrestore')->name('blogrestore');
});


Route::post('/add-to-cart/{productId}', [CartController::class, 'addToCart'])->name('cart.add');
Route::get('cart', [CartController::class, 'showCart'])->name('cart.show');
Route::post('cart/add/{productId}', [CartController::class, 'addToCart'])->name('cart.add');
Route::post('cart/update/{productId}', [CartController::class, 'updateCart'])->name('cart.update');
Route::post('cart/remove/{productId}', [CartController::class, 'removeFromCart'])->name('cart.remove');
Route::post('cart/clear', [CartController::class, 'clearCart'])->name('cart.clear');
Route::post('/cart/add/{productId}', [CartController::class, 'add'])->name('cart.add');
Route::post('cart/clear', [CartController::class, 'clearCart'])->name('cart.clear');
Route::post('cart/remove/{productId}', [CartController::class, 'remove'])->name('cart.remove');
Route::get('cart', [CartController::class, 'clearCart'])->name('cart.index');
Route::post('cart/add/{productId}', [CartController::class, 'add'])->name('cart.add');
Route::get('/checkout', [Billing::class, 'showCheckoutPage'])->name(name: 'checkout');
Route::post('/place-order', [Billing::class, 'placeOrder'])->name('checkout.placeOrder');
Route::get('/billing', [Billing::class, 'billingadd'])->name('billingpage');
Route::get('/billing', [Billing::class, 'billingcreate'])->name('billingadd');
Route::post('/billing', [Billing::class, 'billingstore']);
Route::get('/contact', [ContactController::class, 'contactcreate'])->name('contactcreate');
Route::post('/contact', [ContactController::class, 'contactstore']);



//Billing
Route::prefix('/')->controller(Billing::class)->middleware('admin')->group(function () {
    Route::get('/billingshow', 'billingshow')->name('billingshow');
    Route::get('/billingedit/{id}', 'billingedit')->name('billingedit');
    Route::post('/billingupdate/{id}', 'billingupdate')->name('billingupdate');
    Route::get('/billingdelete/{id}', 'billingdelete')->name('billingdelete');
    Route::get('/billingtrash', 'billingtrash')->name('billingtrash');
    Route::get('/billingrestore/{id}', 'billingrestore')->name('billingrestore');
    Route::get('/billingperment/{id}', 'billingperment')->name('billingperment');
});

//contact
Route::prefix('/')->controller(ContactController::class)->middleware('admin')->group(function () {
    Route::get('/contactshow', 'contactshow')->name('contactshow');
    Route::get('/contactedit/{id}', 'contactedit')->name('contactedit');
    Route::post('/contactupdate/{id}', 'contactupdate')->name('contactupdate');
    Route::get('/contactdelete/{id}', 'contactdelete')->name('contactdelete');
    Route::get('/contacttrash', 'contacttrash')->name('contacttrash');
    Route::get('/contactrestore/{id}', action: 'contactrestore')->name('contactrestore');
    Route::get('/contactperment/{id}', 'contactperment')->name('contactperment');
});